==> haskell-chimera-0.4.0.0-8-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-chimera.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chimera
version:              0.4.0.0
visibility:           public
id:                   chimera-0.4.0.0-L8oqjafv2IM5r4mhm1e5ST
key:                  chimera-0.4.0.0-L8oqjafv2IM5r4mhm1e5ST
license:              BSD-3-Clause
copyright:            2017-2019 Bodigrim
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/chimera#readme
synopsis:
    Lazy infinite streams with O(1) indexing and applications for memoization

description:
    There are plenty of memoizing libraries on Hackage, but they
    usually fall into two categories:

    * Store cache as a flat array, enabling us
    to obtain cached values in O(1) time, which is nice.
    The drawback is that one must specify the size
    of the array beforehand,
    limiting an interval of inputs,
    and actually allocate it at once.
    * Store cache as a lazy binary tree.
    Thanks to laziness, one can freely use the full range of inputs.
    The drawback is that obtaining values from a tree
    takes logarithmic time and is unfriendly to CPU cache,
    which kinda defeats the purpose.

    This package intends to tackle both issues,
    providing a data type '\''Chimera'\'' for
    lazy infinite compact streams with cache-friendly O(1) indexing.

    Additional features include:

    * memoization of recursive functions and recurrent sequences,
    * memoization of functions of several, possibly signed arguments,
    * efficient memoization of boolean predicates.

category:             Data
abi:                  8437d863b22a8b287e422f0b7f29aec0
exposed:              True
exposed-modules:
    Data.Chimera Data.Chimera.ContinuousMapping
    Data.Chimera.WheelMapping

hidden-modules:
    Data.Chimera.Compat Data.Chimera.FromIntegral Data.Chimera.Internal
    Data.Chimera.Memoize

import-dirs:          /usr/lib/ghc-9.2.8/site-local/chimera-0.4.0.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/chimera-0.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chimera
hs-libraries:         HSchimera-0.4.0.0-L8oqjafv2IM5r4mhm1e5ST
depends:
    adjunctions-4.4.2-ArJqvIz7v91Lf8ZLBi2rfM base-4.16.4.0
    distributive-0.6.2.1-Bx2F0eAgMfT82Es2djCngR
    infinite-list-0.1.1-wkxSRy9ADLFKqgKn6yJty mtl-2.2.2
    primitive-0.7.4.0-A9DQl7IN10ADdryf8HN1sF transformers-0.5.6.2
    vector-0.13.1.0-FqETZo7rR6n5zX4PwJIjNh

haddock-interfaces:   /usr/share/doc/haskell-chimera/html/chimera.haddock
haddock-html:         /usr/share/doc/haskell-chimera/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chimera-0.4.1.0-6-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-chimera.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 chimera
version:              0.4.1.0
visibility:           public
id:                   chimera-0.4.1.0-8sJlUR5WVJuH2460HPmgyT
key:                  chimera-0.4.1.0-8sJlUR5WVJuH2460HPmgyT
license:              BSD-3-Clause
copyright:            2017-2019 Bodigrim
maintainer:           andrew.lelechenko@gmail.com
author:               Bodigrim
homepage:             https://github.com/Bodigrim/chimera#readme
synopsis:
    Lazy infinite streams with O(1) indexing and applications for memoization

description:
    There are plenty of memoizing libraries on Hackage, but they
    usually fall into two categories:

    * Store cache as a flat array, enabling us
    to obtain cached values in O(1) time, which is nice.
    The drawback is that one must specify the size
    of the array beforehand,
    limiting an interval of inputs,
    and actually allocate it at once.
    * Store cache as a lazy binary tree.
    Thanks to laziness, one can freely use the full range of inputs.
    The drawback is that obtaining values from a tree
    takes logarithmic time and is unfriendly to CPU cache,
    which kinda defeats the purpose.

    This package intends to tackle both issues,
    providing a data type '\''Chimera'\'' for
    lazy infinite compact streams with cache-friendly O(1) indexing.

    Additional features include:

    * memoization of recursive functions and recurrent sequences,
    * memoization of functions of several, possibly signed arguments,
    * efficient memoization of boolean predicates.

category:             Data
abi:                  2d463beb75bc4f18955530d0da842865
exposed:              True
exposed-modules:
    Data.Chimera Data.Chimera.ContinuousMapping
    Data.Chimera.WheelMapping

hidden-modules:
    Data.Chimera.Compat Data.Chimera.FromIntegral Data.Chimera.Internal
    Data.Chimera.Memoize

import-dirs:          /usr/lib/ghc-9.2.8/site-local/chimera-0.4.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/chimera-0.4.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chimera
hs-libraries:         HSchimera-0.4.1.0-8sJlUR5WVJuH2460HPmgyT
depends:
    adjunctions-4.4.2-His7oR9VCVABqsJvWx17lq base-4.16.4.0
    distributive-0.6.2.1-KvikcorRvGbIZwiFjHIAfQ
    infinite-list-0.1.1-9xKaT7EiNRGDfKwJvpGTWs mtl-2.2.2
    primitive-0.7.4.0-AQ7cOoBXu5aBgAQTQzTLUx transformers-0.5.6.2
    vector-0.13.1.0-xP3uH1g3cPFld8g0jCD5r

haddock-interfaces:   /usr/share/doc/haskell-chimera/html/chimera.haddock
haddock-html:         /usr/share/doc/haskell-chimera/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
